@@ -8,10 +8,16 @@
 #else
     #include <QtDBus>
     #include "maemo5deviceevents.h"
+    #include "mafwrendereradapter.h"
 #endif
 
 #include "ui_widget.h"
 
+#define prevButtonIcon "/etc/hildon/theme/mediaplayer/Back.png"
+#define playButtonIcon "/etc/hildon/theme/mediaplayer/Play.png"
+#define pauseButtonIcon "/etc/hildon/theme/mediaplayer/Pause.png"
+#define nextButtonIcon "/etc/hildon/theme/mediaplayer/Forward.png"
+
 namespace Ui {
     class Widget;
 }
@@ -33,9 +39,11 @@ public:
 
 private:
     QDesktopWidget *desktop;
+    QTimer *mediaplayerTimer;
 #ifdef Q_WS_MAEMO_5
     bool isProximityClosed();
     Maemo5DeviceEvents *deviceEvents;
+    MafwRendererAdapter *renderer;
 #endif
 
 private slots:
@@ -43,10 +51,13 @@ private slots:
     void onProximityChanged();
     void onTimerFinished();
     void connectSignals();
+    void onMediaPlayerPressed();
+    void enableButton1();
 #ifdef Q_WS_MAEMO_5
     void startPoximityd();
     void stopProximityd();
     void onScreenLocked(bool);
+    void onStateChanged(int);
 #endif
 };
 
